@@ -68,4 +68,11 @@
 #undef HAS_SETGROUPS
 #undef HAS_GETGROUPS
 #undef HAS_FCNTL
+#undef HAS_STRSIGNAL
+
+/* mingw has empty stub 
+ * Interesting: https://nanohub.org/infrastructure/rappture/svn/tags/1.0/gui/src/RpWinResource.c
+ */
+#undef HAS_RLIMIT
+
 #undef I_SYS_WAIT
